
#import "KMHTTPManager.h"
#define fURLWithPath(path) [NSString stringWithFormat:@"http://%@%@", KMHTTPManager.serverDomain, (path)]

typedef NSString *const KMKHttpConst;

static KMKHttpConst cancelOrder = @"/demo/s/sdk/orderCancel";
static KMKHttpConst submitOrder = @"/demo/s/sdk/submitOrder";
static KMKHttpConst getImsi = @"/demo/s/sdk/getImsi";
static KMKHttpConst queryOrder = @"/demo/s/sdk/orderDetail";

static NSString *_serverDomain = nil;

@import AFNetworking;

@implementation KMHTTPManager

+ (NSString *)serverDomain {
    if (!_serverDomain) {
        NSDictionary *info = NSBundle.mainBundle.infoDictionary;
        _serverDomain = info[@"ServerDomain"];
    }
    return _serverDomain;
}

+ (void)getImsi:(NSString *)orderId iccid:(NSString *)iccid result:(HttpRequestResult)result
{
    NSString *url = fURLWithPath(getImsi);
    NSDictionary *parameters = @{
                                 @"sysOrderId" : orderId,
                                 @"iccid": iccid
                                 };
    [self requestWithUrl:url parameters:parameters result:result];
}

+ (void)submitOrder:(NSString *)orderId iccid:(NSString *)iccid result:(HttpRequestResult)result
{
    NSString *url = fURLWithPath(submitOrder);
    NSDictionary *parameters = @{@"sysOrderId" : orderId,
                                 @"iccid" : iccid};
    [self requestWithUrl:url parameters:parameters result:result];
}

+ (void)cancelOrder:(NSString *)orderId result:(HttpRequestResult)result
{
    NSString *url = fURLWithPath(cancelOrder);
    NSDictionary *parameters = @{@"sysOrderId" : orderId};
    [self requestWithUrl:url parameters:parameters result:result];
}

+ (void)queryOrderWithOrderId:(NSString *)orderId step:(KMKOpenCardSteps)step result:(HttpRequestResult)result {
    NSString *url = fURLWithPath(queryOrder);
    NSString *stepCode = [KamengKit stepCodeWithStep:step];
    NSDictionary *parameters = @{@"sysOrderId" : orderId,
                                 @"searchType" : stepCode};
    [self requestWithUrl:url parameters:parameters result:result];
}

+ (void)requestWithUrl:(NSString *)url parameters:(NSDictionary *)dict result:(HttpRequestResult)result {
    NSMutableDictionary *parameters = [NSMutableDictionary dictionaryWithDictionary:dict];  
    [parameters setObject:KMAppId forKey:@"appId"];
    [parameters setObject:KMAppKey forKey:@"appKey"];

    AFHTTPSessionManager *manager = [AFHTTPSessionManager manager];
    
    manager.requestSerializer = [AFJSONRequestSerializer serializer];
    manager.responseSerializer = [AFJSONResponseSerializer serializer];
    
    [manager POST:url parameters:parameters progress:^(NSProgress * _Nonnull uploadProgress) {
            
    } success:^(NSURLSessionDataTask * _Nonnull task, id  _Nullable responseObject) {
//        NSLog(@"\n请求成功 URL:%@\n%@", url, responseObject);
        result(responseObject, nil);
    } failure:^(NSURLSessionDataTask * _Nullable task, NSError * _Nonnull error) {
//        NSLog(@"\n请求失败 URL:%@\n%@", url, error);
        result(nil, error);
    }];
}

@end
