
#import "KMViewController.h"
#import "KMHTTPManager.h"
//#import <KamengKit/KamengKit.h>
////@import KamengKit;

@interface KMViewController ()

@property (weak, nonatomic) IBOutlet UILabel *usernameLabel;
@property (weak, nonatomic) IBOutlet UILabel *orderLabel;
@property (weak, nonatomic) IBOutlet UITextView *orderDetailTextView;
@property (weak, nonatomic) IBOutlet UISwitch *queryBySdkSwitch;

@end

@implementation KMViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = @"卡盟Demo";
    _usernameLabel.text = KMUser.currentUser.username;
    
    UIBarButtonItem *item = [[UIBarButtonItem alloc] init];
    item.title = @"";
    self.navigationItem.backBarButtonItem = item;
    [NSNotificationCenter.defaultCenter addObserver:self
                                           selector:@selector(orderDidCancel:) 
                                               name:KMOrderDidCancelNotification
                                             object:nil];
}

- (void)dealloc {
    [NSNotificationCenter.defaultCenter removeObserver:self];
}

- (void)orderDidCancel:(NSNotification *)notification {
    self.order = nil;
    _orderLabel.text = nil;
}

- (IBAction)choosenumber:(UIButton *)sender {
    __weak typeof(self) weakSelf = self;
    UIViewController *webView = [KamengKit starOpenCardWithUserId:KMUser.currentUser.username completion:^(KMKOrder *order, NSError *error) {
        [weakSelf ordingSucceedWithOrder:order error:error];
    }];

    [self.navigationController showViewController:webView sender:nil];
}

- (IBAction)onQueryOrder:(UIButton *)sender {
    if (!self.order) {
        [self showAlertWithTitle:nil message:@"请先选号、选套餐"];
        return;
    }
    KMKOpenCardSteps step = 1 << sender.tag;
    NSString *orderId = self.order.orderId;
    __weak typeof(self) weakSelf = self;
    id result = ^(NSDictionary *responseObject, NSError *error) {
        [weakSelf indicatorStopAnimate];
        [weakSelf queryOrderStep:step response:responseObject error:error];
    };
    [self indicatorStartAnimate:@""];
    if (_queryBySdkSwitch.on) {
        [KamengKit queryOrderWithOrderId:orderId step:step result:result];
    }
    else {
        [KMHTTPManager queryOrderWithOrderId:orderId step:step result:result];
    }
}

- (IBAction)onGoNextStep:(UIButton *)sender {
    if (!self.order) {
        [self showAlertWithTitle:nil message:@"请先生成订单"];
        return;
    }
    [self performSegueWithIdentifier:@"showWriteCard" sender:self.order];
}

- (void)ordingSucceedWithOrder:(KMKOrder *)order error:(NSError *)error {
    if (error) {
        [self showAlertWithTitle:nil message:error.localizedDescription];
        return;
    }
    self.order = order;
    NSString *orderDetail = [NSString stringWithFormat:@"订单号：%@", order.orderId];
    _orderLabel.text = orderDetail;
    [self.navigationController popToViewController:self animated:YES];
}

- (void)queryOrderStep:(KMKOpenCardSteps)step response:(NSDictionary *)response error:(NSError *)error {
    if (error) {
        [self showAlertWithTitle:nil message:error.localizedDescription];
    }
    else {
        NSString *text = [NSString stringWithFormat:@"%@", response[@"data"]];
        text = [[NSString alloc] initWithData:[text dataUsingEncoding:NSUTF8StringEncoding] encoding:NSUTF8StringEncoding];
        _orderDetailTextView.text = text;
    }
}

#pragma mark - Navigation

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if ([segue.identifier isEqualToString:@"showWriteCard"]) {
        segue.destinationViewController.order = sender;
    }
}

@end
