
#import "KMWriteCardViewController.h"
#import "KMHTTPManager.h"

@interface KMWriteCardViewController ()

@property (weak, nonatomic) IBOutlet UIButton *getImsiButton;

@property (weak, nonatomic) IBOutlet UILabel *imsiLabel;

@property (weak, nonatomic) IBOutlet UIButton *writeCardButton;

@property (weak, nonatomic) IBOutlet UILabel *iccidLabel;

@property (weak, nonatomic) IBOutlet UIButton *commitButton;

@property (nonatomic, copy) NSString *iccid;

@property (nonatomic) BOOL isImsiGot;

@property (nonatomic) BOOL isCardWritten;

@end

@implementation KMWriteCardViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self addGiveUpButton:@selector(showCancelOrderAlert)];
}

- (IBAction)onGetImsi:(UIButton *)sender {
    __weak typeof(self) weakself = self;
    if (!self.order.orderId.length) {
        [self showAlertWithTitle:@"Warn" message:@"no orderId"];
        return;
    }
    if (!self.iccid.length) {
        [self showAlertWithTitle:@"Warn" message:@"no iccid"];
        return;
    }
    [self indicatorStartAnimate:nil];
    [KMHTTPManager getImsi:self.order.orderId iccid: self.iccid result:^(id responseObject, NSError *error) {
        [weakself indicatorStopAnimate];
        [weakself getImsiresponse:responseObject error:error];
    }];
}

- (void)getImsiresponse:(NSDictionary *)responseObject error:(NSError *)error {
    NSString *code = responseObject[@"code"];
    BOOL success = !error && [code isEqualToString:@"200"];
    _isImsiGot = success;
    if (success) {
        NSString *text = [NSString stringWithFormat:@"imsi：%@\nsmsp：%@",
                          responseObject[@"data"][@"imsi"],
                          responseObject[@"data"][@"smsp"]];
        
        _imsiLabel.text = text;
    } else {
        NSString *message = error ? error.localizedDescription : responseObject[@"msg"];
        [self showAlertWithTitle:@"获取IMSI失败" message:message];
    }
}

- (IBAction)onWriteCard:(UIButton *)sender {
    if (!_isImsiGot) {
        [self showAlertWithTitle:nil message:@"请先获取IMSI"];
        return;
    }
    [self indicatorStartAnimate:nil];
    [self performSelector:@selector(writeCardSuccess) withObject:nil afterDelay:4];
}

- (void)writeCardSuccess {
    __weak typeof(self) weakSelf = self;
    dispatch_async(dispatch_get_main_queue(), ^{
        weakSelf.isCardWritten = YES;
        [weakSelf indicatorStopAnimate];
        NSString *iccid = @"93458923459327";
        weakSelf.iccidLabel.text = [NSString stringWithFormat:@"ICCID：%@", iccid]; 
        weakSelf.iccid = iccid;    // 需要从SIM卡中读取ICCID
        
        [self showAlertWithTitle:nil message:@"写卡完成"];
    });
}


- (IBAction)onCommit:(UIButton *)sender {
    if (!_isImsiGot) {
        [self showAlertWithTitle:nil message:@"请先获取IMSI"];
        return;
    }
    if (!_isCardWritten) {
        [self showAlertWithTitle:nil message:@"请先写卡"];
        return;
    }
    
    __weak typeof(self) weakSelf = self;
    [self indicatorStartAnimate:nil];
    [KMHTTPManager submitOrder:self.order.orderId iccid:self.iccid result:^(id responseObject, NSError *error) {
        [weakSelf indicatorStopAnimate];
        [weakSelf submitOrderResponse:responseObject error:error];
    }];
}

- (void)submitOrderResponse:(NSDictionary *)responseObject error:(NSError *)error {
    
    NSString *code = responseObject[@"code"];
    if (![code isEqualToString:@"685"] || error != nil) {
        NSString *message = error ? error.localizedDescription : responseObject[@"msg"];
        [self showAlertWithTitle:nil message:message];
        return;
    }
    
    __weak typeof(self) weakSelf = self;
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"开卡完成" message:nil preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *action = [UIAlertAction actionWithTitle:@"好的" style:UIAlertActionStyleCancel handler:^(UIAlertAction * _Nonnull action) {
        [weakSelf.navigationController popToRootViewControllerAnimated:YES];
    }];
    [alert addAction:action];
    [self presentViewController:alert animated:YES completion:nil];
}

- (void)showCancelOrderAlert {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"提示" message:@"你确定要放弃订单吗？" preferredStyle:UIAlertControllerStyleAlert];
    
    __weak typeof(self) weakself = self;
    [alert addAction:[UIAlertAction actionWithTitle:@"放弃订单" style:UIAlertActionStyleDestructive handler:^(UIAlertAction * _Nonnull action) {
        [weakself cancelOrder];
    }]];
    
    [alert addAction:[UIAlertAction actionWithTitle:@"我再想想" style:UIAlertActionStyleCancel handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (void)cancelOrder {
    __weak typeof(self) weakself = self;
    [self indicatorStartAnimate:nil];
    [KMHTTPManager cancelOrder:self.order.orderId result:^(id responseObject, NSError *error) {
        [weakself cancelOrderResult:responseObject error:error];
    }];
}

- (void)cancelOrderResult:(NSDictionary *)responseObject error:(NSError *)error {
    NSString *code = responseObject[@"code"];
    [self indicatorStopAnimate];
    BOOL cancelSuccees = !error && [code isEqualToString:@"200"];
    
    if (cancelSuccees) {
        [NSNotificationCenter.defaultCenter postNotificationName:KMOrderDidCancelNotification object:nil];
        [self.navigationController popToRootViewControllerAnimated:YES];
        return;
    }
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"提示" message:@"取消订单失败" preferredStyle:UIAlertControllerStyleAlert];
    __weak typeof(self) weakSelf = self;
    [alert addAction:[UIAlertAction actionWithTitle:@"返回主页" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        [weakSelf.navigationController popToRootViewControllerAnimated:YES];
    }]];
    
    [alert addAction:[UIAlertAction actionWithTitle:@"取消" style:UIAlertActionStyleDefault handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}

@end
