
#import <UIKit/UIKit.h>
#import <KamengKit/KMKOpenCardSteps.h>
#import <KamengKit/KMKOrder.h>


/// 查询订单信息回调
///
/// @param responseObject 服务器响应结果 请求失败为nil
/// @param error 错误信息 请求成功为nil
typedef void (^KMKHttpRequestResult)(NSDictionary *responseObject, NSError *error);

/// 选号选套餐结束的回调
///
/// @param order 开卡订单
/// @param error 错误信息
typedef void (^KMKChooseNumberCompletion)(KMKOrder *order, NSError *error);


@interface KamengKit : NSObject

/// 注册应用
/// @param appId 申请远特开卡时远特分配的id
/// @param appKey 申请远特开卡时远特分配的key
+ (void)registerApp:(NSString *)appId appKey:(NSString *)appKey;

/// 开始选号
/// @param userId 当前用户Id
/// @param completion 选号选套餐结束的回调
/// @return 选号选套餐视图控制器，需要用 UINavigationController Push 出来。
+ (UIViewController *)starOpenCardWithUserId:(NSString *)userId
                                  completion:(KMKChooseNumberCompletion)completion;

/// 查询订单选号详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsChooseNumber result:result];
+ (void)queryChooseNumberDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单套餐详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsChoosePackage result:result];
+ (void)queryChoosePackageDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单上传用户信息详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsUploadInfo result:result];
+ (void)queryUploadInfoDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单支付详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsPayment result:result];
+ (void)queryPaymentDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单审核详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsReview result:result];
+ (void)queryReviewDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单写卡详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsWriteCard result:result];
+ (void)queryWriteCardDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;

/// 查询订单激活详情, 等同于[self queryOrderWithOrderId:orderId step:KMKOpenCardStepsActivatetion result:result];
+ (void)queryActivatetionDetailWithOrderId:(NSString *)orderId result:(KMKHttpRequestResult)result;


/// 查询当前订单状态
/// @param orderId 订单ID
/// @param step 开卡步骤
/// @param result 查询结果
+ (void)queryOrderWithOrderId:(NSString *)orderId
                         step:(KMKOpenCardSteps)step
                       result:(KMKHttpRequestResult)result;

/// 根据步骤获取步骤码
+ (NSString *)stepCodeWithStep:(KMKOpenCardSteps)step;

@end
